List Statistics Canada PUMF datasets supported by canpumf
Source:R/pumf_collection.R
list_canpumf_collection.RdReturns a tibble of all survey series and versions for which canpumf has download wrappers. Scrapes the StatCan website to discover Census versions; other series are hard-coded. Requires an internet connection.
Value
A tibble with columns `Title`, `Acronym`, `Version`, `Survey Number`, and `url`. The `url` column contains the download URL or `"(EFT)"` for versions distributed via the Research Data Centre (EFT only). Pass `Acronym` and `Version` to [get_pumf()] to download a dataset.
Examples
if (FALSE) { # \dontrun{
collection <- list_canpumf_collection()
# Show all SFS versions
collection[collection$Acronym == "SFS", c("Acronym", "Version")]
} # }